#------------------------------------------------------------------------------
# University of Ulm, Faculty of Mathematics and Economics
# afb 6/98
#------------------------------------------------------------------------------
# support of tables of relational databases on base of DBI/MySQL
#------------------------------------------------------------------------------
# $Id$
#------------------------------------------------------------------------------
# $Log$
#------------------------------------------------------------------------------

package TBD::DBI::MySQL;

use Carp;
use DBI;
use TBD::DBI;
use strict;
use warnings;

our @ISA = qw(TBD::DBI);
our $VERSION = "0.02";

#------------------------------------------------------------------------------

=head1 NAME

TBD::DBI::MySQL -- table driver for MySQL databases

=head1 DESCRIPTION

I<TBD::DBI::MySQL> is derived from I<TBD::DBI> and supports MySQL
databases for the table interface.

Following code snippet could be a good candidate for your
I<TBI_Scanner> package that registers all tables of a
MySQL database:

   package TBI_Scanner;

   use DBI;
   use Mysql::Admin qw(dbi_connect);
   use TBD::DBI::MySQL;
   use TBI;
   use strict;
   use warnings;

   my $dbdir = "/data/directory/of/MySQL/";

   sub scan {
      my $db = DBI->connect(dbi_connect($dbdir), "", "");
      my @tables = TBD::DBI::MySQL->tables($db);
      $db->disconnect;
      if (@tables > 0) {
	 my $table = new TBD::DBI::MySQL(
	    database => dbi_connect($dbdir),
	    login => '', 'auth' => '',
	    table => $tables[0],
	    tablename => $tables[0]
	 );
	 $table->close;
      };
   }

   1;

=head1 AUTHOR

=for html
<A HREF="http://www.mathematik.uni-ulm.de/sai/borchert/">Andreas Borchert</A>

=for text
Andreas Borchert

=cut

#------------------------------------------------------------------------------
sub tables {
   my ($package, $db) = @_;
   my $st = $db->prepare("show tables");
   $st->execute();
   my @tables = ();
   my $record;
   while (defined($record = $st->fetch())) {
      push(@tables, $record->[0]);
   }
   $st->finish;
   return @tables;
}
#------------------------------------------------------------------------------
sub initialize2 {
   my ($self) = @_;

   my $st = $self->{db}->prepare(qq{
      show index from $self->{table}
   });
   $st->execute();
   my @keyfields = ();
   my $record;
   while (defined($record = $st->fetchrow_hashref())) {
      next unless $record->{Key_name} eq "PRIMARY";
      $keyfields[$record->{Seq_in_index}] = $record->{Column_name};
   }
   $st->finish();

   shift @keyfields; # Seq_in_index is running from 1
   croak "no primary key defined" unless @keyfields > 0;
   $self->{keyfields} = \@keyfields;

   $self->SUPER::initialize2();
}
#------------------------------------------------------------------------------

1;
