#------------------------------------------------------------------------------
# University of Ulm, Faculty of Mathematics and Economics
# afb 2/96
#------------------------------------------------------------------------------
# General dumping algorithm for tables
#------------------------------------------------------------------------------

package TBD::Dumper;
use Carp;
use English;
use TBI;
use strict;
use warnings;

our $VERSION = "0.02";
our @ISA = qw(TBI);

=head1 NAME

TBD::Dumper - a general dumping algorithm for tables

=head1 SYNOPSIS

   use TBD::Dumper;
   our @ISA = qw(... TBD::Dumper ...);

=head1 DESCRIPTION

TBD::Dumper provides a general algorithm for dumping tables
to text files that is based upon following internal variables:

=over 4

=item ofs

The output field separator that is to be used on storing
modificated tables back to the original file.

=item ors

The output record separator.

=item header

A list of lines which are to be printed at the beginning.

=back

Following operation is defined:

=over 4

=item $table->dump($handle)

dumps the table from the table $table->{table} to the given output file
handle.  The output is generated under consideration of $table->{ofs}
(output field seperator) and $table->{ors} (output record separator).
The fields are generated in the same order as returned by $table->fields.

True is return in case of success, 0 in case of output failures.

=back

=head1 AUTHOR

=for html
<A HREF="http://www.mathematik.uni-ulm.de/sai/borchert/">Andreas Borchert</A>

=for text
Andreas Borchert

=for man
Andreas Borchert

=cut

sub dump {
   my ($table, $handle) = @_;
   my $ofs = $table->{ofs};
   my $ors = $table->{ors};

   if (@{$table->{header}} > 0) {
      print $handle join($ors, @{$table->{header}}), $ors or return 0;
   }
   foreach my $key ($table->keys) {
      my @fields = $table->get($key, $table->fields);
      print $handle join($ofs, @fields), $ors or return 0;
   }
   return 1;
}

1;
