#!/usr/local/bin/perl -w

use Test;
use strict;

BEGIN { plan tests => 17 }

use TBI;
use TBD::Text;
use Fcntl;

my %table = (
   "A" => {
      'ifs' => ':',
      'irs' => "\n",
      'keyfields' => [qw(a)],
      'fields' => [qw(a b c)],
   },
   "B" => {
      'ifs' => '~',
      'irs' => "\n",
      'keyfields' => [qw(a b)],
      'fields' => [qw(a b c d)],
   },
);

my %contents = (
"A" => <<END_OF_A,
1:foo:bar
2:bar:foo
3:ulm:koeln
4:ulm:york
END_OF_A
"B" => <<END_OF_B,
1~eins~one~une
1~one~une~eins
2~zwei~two~deux
2~two~deux~zwei
END_OF_B
);

foreach my $file (keys %contents) {
   my $out = new IO::File "tmp.$file.db", O_WRONLY|O_TRUNC|O_CREAT;
   die "unable to create tmp.$file.db: $!" unless defined $out;
   print $out $contents{$file}; $out->close;
}

foreach my $table (keys %table) {
   TBI->register($table, 'TBD::Text', {
      'filename' => "tmp.$table.db",
      'tablename' => $table,
      %{$table{$table}},
   });
}

my ($a, $b);
ok($a = TBI->open("A")); # 1
ok($b = TBI->open("B")); # 2
ok($a->load); # 3
ok($b->load); # 4

ok(join(":", $a->fields), "a:b:c"); # 5
ok(join(":", $a->keyfields), "a"); # 6
ok($a->name, "A"); # 7
ok($a->exists("1")); # 8
ok($a->exists("2")); # 9
ok($a->exists("3")); # 10
ok($a->exists("4")); # 11
ok(join(":", sort $a->keys), "1:2:3:4"); # 12
ok(sub { my %fields = $a->fetch("3"); $fields{'c'} }, "koeln"); # 13
ok(join(":", $a->get("2", qw(c b a))), "foo:bar:2"); # 14
ok(join(":", sort $a->select('b' => 'ulm')), "3:4"); # 15

ok(sub {
   my %fields = $b->fetch({'a' => '2', 'b' => 'zwei'});
   $fields{'c'}
}, "two"); # 16
ok(sub {
   my %fields = $b->fetch({'b' => 'zwei', 'a' => '2'});
   $fields{'d'}
}, "deux"); # 17
