#!/usr/local/bin/perl -w

use Test;
use strict;

BEGIN { plan tests => 11 }

use TBI;
use TBD::Text;
use Fcntl;

my %table = (
   "A" => {
      'ifs' => ':',
      'irs' => "\n",
      'keyfields' => [qw(a)],
      'fields' => [qw(a b c)],
   },
   "B" => {
      'ifs' => '~',
      'irs' => "\n",
      'keyfields' => [qw(a b)],
      'fields' => [qw(a b c d)],
   },
);

my %contents = (
"A" => <<END_OF_A,
1:foo:bar
2:bar:foo
3:ulm:koeln
4:ulm:york
END_OF_A
"B" => <<END_OF_B,
1~eins~one~une
1~one~une~eins
2~zwei~two~deux
2~two~deux~zwei
END_OF_B
);

foreach my $file (keys %contents) {
   my $out = new IO::File "tmp.$file.db", O_WRONLY|O_TRUNC|O_CREAT;
   die "unable to create tmp.$file.db: $!" unless defined $out;
   print $out $contents{$file}; $out->close;
}

foreach my $table (keys %table) {
   TBI->register($table, 'TBD::Text', {
      'filename' => "tmp.$table.db",
      'tablename' => $table,
      %{$table{$table}},
   });
}

my ($a, $b);
ok($a = TBI->open("A")); # 1
ok($b = TBI->open("B")); # 2
ok($a->lock); # 3
ok($b->lock); # 4

ok(sub {
   $a->modify('2', 'b' => 'foo');
   $a->getfield('2', 'b');
}, "foo"); # 5
ok(sub {
   $a->add('5', 'a' => '5', 'b' => 'ulm', 'c' => 'ssv');
   ($a->select('c' => 'ssv'))[0];
}, "5"); # 6
my @x = ($a->select('c' => 'ssv'));
ok(sub {
   $a->delete('3');
   !$a->exists('3');
}); # 7

ok($a->unlock); # 8;
ok($a->lock); # 9;

ok($a->getfield('2', 'b'), "foo"); # 10
ok(($a->select('c' => 'ssv'))[0], "5"); # 11;
